# This file was auto-generated by Fern from our API Definition.

import typing
from ...core.client_wrapper import SyncClientWrapper
from ...core.request_options import RequestOptions
from ...types.scim_settings import ScimSettings
from ...core.unchecked_base_model import construct_type
from json.decoder import JSONDecodeError
from ...core.api_error import ApiError
from ...types.project_group_request import ProjectGroupRequest
from ...types.scim_settings_update import ScimSettingsUpdate
from ...core.serialization import convert_and_respect_annotation_metadata
from ...core.client_wrapper import AsyncClientWrapper

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class ScimClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def get(self, *, request_options: typing.Optional[RequestOptions] = None) -> ScimSettings:
        """
        <Card href="https://humansignal.com/goenterprise">
                <img style="pointer-events: none; margin-left: 0px; margin-right: 0px;" src="https://docs.humansignal.com/images/badge.svg" alt="Label Studio Enterprise badge"/>
                <p style="margin-top: 10px; font-size: 14px;">
                    This endpoint is not available in Label Studio Community Edition. [Learn more about Label Studio Enterprise](https://humansignal.com/goenterprise)
                </p>
            </Card>
        Retrieve SCIM settings for the currently active organization.

        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ScimSettings


        Examples
        --------
        from label_studio_sdk import LabelStudio

        client = LabelStudio(
            api_key="YOUR_API_KEY",
        )
        client.sso.scim.get()
        """
        _response = self._client_wrapper.httpx_client.request(
            "api/scim/settings",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    ScimSettings,
                    construct_type(
                        type_=ScimSettings,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def update(
        self,
        *,
        projects_groups: typing.Optional[typing.Sequence[ProjectGroupRequest]] = OMIT,
        roles_groups: typing.Optional[typing.Sequence[typing.Sequence[str]]] = OMIT,
        workspaces_groups: typing.Optional[typing.Sequence[typing.Sequence[str]]] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ScimSettingsUpdate:
        """
        <Card href="https://humansignal.com/goenterprise">
                <img style="pointer-events: none; margin-left: 0px; margin-right: 0px;" src="https://docs.humansignal.com/images/badge.svg" alt="Label Studio Enterprise badge"/>
                <p style="margin-top: 10px; font-size: 14px;">
                    This endpoint is not available in Label Studio Community Edition. [Learn more about Label Studio Enterprise](https://humansignal.com/goenterprise)
                </p>
            </Card>
        Update SCIM settings for the currently active organization.

        Parameters
        ----------
        projects_groups : typing.Optional[typing.Sequence[ProjectGroupRequest]]

        roles_groups : typing.Optional[typing.Sequence[typing.Sequence[str]]]

        workspaces_groups : typing.Optional[typing.Sequence[typing.Sequence[str]]]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ScimSettingsUpdate


        Examples
        --------
        from label_studio_sdk import LabelStudio, ProjectGroupRequest

        client = LabelStudio(
            api_key="YOUR_API_KEY",
        )
        client.sso.scim.update(
            projects_groups=[
                ProjectGroupRequest(
                    group="groups_test",
                    project_id=42,
                    role="Inherit",
                )
            ],
            roles_groups=[["Administrator", "groups_test"]],
            workspaces_groups=[["Default workspace", "groups_test"]],
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            "api/scim/settings",
            method="POST",
            json={
                "projects_groups": convert_and_respect_annotation_metadata(
                    object_=projects_groups, annotation=typing.Sequence[ProjectGroupRequest], direction="write"
                ),
                "roles_groups": roles_groups,
                "workspaces_groups": workspaces_groups,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    ScimSettingsUpdate,
                    construct_type(
                        type_=ScimSettingsUpdate,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)


class AsyncScimClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def get(self, *, request_options: typing.Optional[RequestOptions] = None) -> ScimSettings:
        """
        <Card href="https://humansignal.com/goenterprise">
                <img style="pointer-events: none; margin-left: 0px; margin-right: 0px;" src="https://docs.humansignal.com/images/badge.svg" alt="Label Studio Enterprise badge"/>
                <p style="margin-top: 10px; font-size: 14px;">
                    This endpoint is not available in Label Studio Community Edition. [Learn more about Label Studio Enterprise](https://humansignal.com/goenterprise)
                </p>
            </Card>
        Retrieve SCIM settings for the currently active organization.

        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ScimSettings


        Examples
        --------
        import asyncio

        from label_studio_sdk import AsyncLabelStudio

        client = AsyncLabelStudio(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.sso.scim.get()


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            "api/scim/settings",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    ScimSettings,
                    construct_type(
                        type_=ScimSettings,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def update(
        self,
        *,
        projects_groups: typing.Optional[typing.Sequence[ProjectGroupRequest]] = OMIT,
        roles_groups: typing.Optional[typing.Sequence[typing.Sequence[str]]] = OMIT,
        workspaces_groups: typing.Optional[typing.Sequence[typing.Sequence[str]]] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ScimSettingsUpdate:
        """
        <Card href="https://humansignal.com/goenterprise">
                <img style="pointer-events: none; margin-left: 0px; margin-right: 0px;" src="https://docs.humansignal.com/images/badge.svg" alt="Label Studio Enterprise badge"/>
                <p style="margin-top: 10px; font-size: 14px;">
                    This endpoint is not available in Label Studio Community Edition. [Learn more about Label Studio Enterprise](https://humansignal.com/goenterprise)
                </p>
            </Card>
        Update SCIM settings for the currently active organization.

        Parameters
        ----------
        projects_groups : typing.Optional[typing.Sequence[ProjectGroupRequest]]

        roles_groups : typing.Optional[typing.Sequence[typing.Sequence[str]]]

        workspaces_groups : typing.Optional[typing.Sequence[typing.Sequence[str]]]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ScimSettingsUpdate


        Examples
        --------
        import asyncio

        from label_studio_sdk import AsyncLabelStudio, ProjectGroupRequest

        client = AsyncLabelStudio(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.sso.scim.update(
                projects_groups=[
                    ProjectGroupRequest(
                        group="groups_test",
                        project_id=42,
                        role="Inherit",
                    )
                ],
                roles_groups=[["Administrator", "groups_test"]],
                workspaces_groups=[["Default workspace", "groups_test"]],
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            "api/scim/settings",
            method="POST",
            json={
                "projects_groups": convert_and_respect_annotation_metadata(
                    object_=projects_groups, annotation=typing.Sequence[ProjectGroupRequest], direction="write"
                ),
                "roles_groups": roles_groups,
                "workspaces_groups": workspaces_groups,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    ScimSettingsUpdate,
                    construct_type(
                        type_=ScimSettingsUpdate,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)
